+++++++++++++++++++++++++++++++++
Django Mariposa
+++++++++++++++++++++++++++++++++


::

    pip install django-mariposa


put `django_mariposa` in `INSTALLED_APPS`

add the `MARIPOSA_DIRECTORY` setting.

Go to that directory and `mariposa create` your migration files and edit them.

Now you can::

    ./manage.py migrate
